@@ -148,7 +148,7 @@ class BertSTEMForTextClassification:
 
         text = df[col_text].values
         
-        encoded_text = self.tokenizer.batch_encode_plus(list(text),                # Sentence to encode.
+        encoded_text = self._tokenizer.batch_encode_plus(list(text),                # Sentence to encode.
                                                         add_special_tokens = True, # Add '[CLS]' and '[SEP]'
                                                         max_length = 120,
                                                         truncation = True,           # Pad & truncate all utterances.
@@ -156,6 +156,6 @@ class BertSTEMForTextClassification:
                                                         return_attention_mask = True,   # Construct attn. masks.
                                                         return_tensors = 'pt')
 
-        logits = self.model(encoded_dict['input_ids'])['logits']
+        logits = self._model(encoded_dict['input_ids'])['logits']
         
         return(torch.nn.Softmax()(logits))
